@@ -13,9 +13,10 @@ class CallNotify(hildondesktop.StatusMenuItem):
     def __init__(self):
 		hildondesktop.StatusMenuItem.__init__(self)
 		# Set members
-		self.Debug = False
 		self.configDir = "/home/user/.config/CallNotify/"
 		self.configFile = "conf.txt"
+		self.Debug = False
+		self.dbg("debugging started")
 		self.readConfigurationFile()
 		self.msgType = ""		
 		self.toShow = True
@@ -61,25 +62,33 @@ class CallNotify(hildondesktop.StatusMenuItem):
 
     def checkForConfigFile(self):
 		self.dbg('checkForConfigFile started')
+		os.umask(0)
 		if not os.path.exists(self.configDir):
         		os.mkdir(self.configDir)
 		if not os.path.exists(self.configDir+self.configFile):
-        		a = open(self.configDir+self.configFile,'w')
-        		a.write('y;y;y;5')
+        		a = open(self.configDir+self.configFile,'w+')
+        		a.write('y;y;y;5.0\n')
         		a.close()
+		# set proper permissions
+		os.system("chmod 766 " + self.configDir)
+		os.system("chmod 766" + self.configDir+self.configFile)
 
                 
     def readConfigurationFile(self):
-		self.dbg('readConfigurationFile started')
-		self.checkForConfigFile()
-		f = open(self.configDir+self.configFile, 'r')
-		raw_set = f.readline().rsplit(';')
-		self.visual = raw_set[0] in ('y')
-		self.sound = raw_set[1] in ('y')
-		self.vibration = raw_set[2] in ('y')
-		self.interval = float(raw_set[3])
-		f.close()
-			
+		try:
+			self.dbg('readConfigurationFile started')
+			self.checkForConfigFile()
+			f = open(self.configDir+self.configFile, 'r')
+			raw_set = f.readline().rsplit(';')
+			self.visual = raw_set[0] in ('y')
+			self.sound = raw_set[1] in ('y')
+			self.vibration = raw_set[2] in ('y')
+			self.interval = float(raw_set[3].replace(',','.'))
+			f.close()
+		except:
+			os.remove(self.configDir+self.configFile)
+			self.checkForConfigFile()
+	
     def saveConfigurationFile(self):
 		self.dbg('saveConfigurationFile started')
 		f = open(self.configDir+self.configFile, "w")
@@ -383,3 +392,13 @@ class CallNotify(hildondesktop.StatusMenuItem):
 		
 hd_plugin_type = CallNotify
 
+
+# Uncomment from "if __name__..." to "gtk.main()" if running from CLI as:
+# "run-standalone.sh python CallNotify.py"
+
+#if __name__=="__main__":
+#		gobject.type_register(hd_plugin_type)
+#		obj = gobject.new(hd_plugin_type, plugin_id="plugid_id")
+#		obj.show_all()
+#		gtk.main()
+
